@@ -7,12 +7,24 @@ import os
 import shutil
 import subprocess
 import sys
-from typing import cast, Any, Callable, Dict, Optional, Union
+from typing import cast, TYPE_CHECKING
 
 import numpy as np
 
 from ffsubsync.aligners import FFTAligner, MaxScoreAligner, FailedToFindAlignmentException
-from ffsubsync.constants import *
+from ffsubsync.constants import (
+    DEFAULT_APPLY_OFFSET_SECONDS,
+    DEFAULT_FRAME_RATE,
+    DEFAULT_MAX_OFFSET_SECONDS,
+    DEFAULT_MAX_SUBTITLE_SECONDS,
+    DEFAULT_NON_SPEECH_LABEL,
+    DEFAULT_START_SECONDS,
+    DEFAULT_VAD,
+    DEFAULT_ENCODING,
+    FRAMERATE_RATIOS,
+    SAMPLE_RATE,
+    SUBTITLE_EXTENSIONS,
+)
 from ffsubsync.ffmpeg_utils import ffmpeg_bin_path
 from ffsubsync.sklearn_shim import Pipeline, TransformerMixin
 from ffsubsync.speech_transformers import (
@@ -24,6 +36,10 @@ from ffsubsync.subtitle_parser import make_subtitle_parser
 from ffsubsync.subtitle_transformers import SubtitleMerger, SubtitleShifter
 from ffsubsync.version import get_version
 
+if TYPE_CHECKING:
+    from typing import Any, Callable, Dict, List, Optional, Tuple, Union
+
+
 logger: logging.Logger = logging.getLogger(__name__)
 
 
@@ -152,7 +168,15 @@ def try_sync(args: argparse.Namespace, reference_pipe: Pipeline, result: Dict[st
             if args.output_encoding != 'same':
                 out_subs = out_subs.set_encoding(args.output_encoding)
             logger.info('writing output to {}'.format(srtout or 'stdout'))
-            out_subs.write_file(srtout)
+            suppress_output_thresh = args.suppress_output_if_offset_less_than
+            if (
+                suppress_output_thresh is None
+                or (
+                    scale_step.scale_factor == 1.0
+                    and offset_seconds >= suppress_output_thresh
+                )
+            ):
+                out_subs.write_file(srtout)
     except FailedToFindAlignmentException as e:
         sync_was_successful = False
         logger.error(e)
@@ -416,15 +440,20 @@ def add_cli_only_args(parser: argparse.ArgumentParser) -> None:
                              'mismatch between reference and subtitles.')
     parser.add_argument('--serialize-speech', action='store_true',
                         help='If specified, serialize reference speech to a numpy array.')
-    parser.add_argument('--extract-subs-from-stream', default=None,
+    parser.add_argument('--extract-subs-from-stream',
+                        '--extract-subtitles-from-stream',
+                        default=None,
                         help='If specified, do not attempt sync; instead, just extract subtitles'
                              ' from the specified stream using the reference.')
+    parser.add_argument('--suppress-output-if-offset-less-than', type=float,
+                        default=None,
+                        help='If specified, do not produce output if offset below provided threshold.')
     parser.add_argument(
         '--ffmpeg-path', '--ffmpegpath', default=None,
         help='Where to look for ffmpeg and ffprobe. Uses the system PATH by default.'
     )
-    parser.add_argument('--log-dir-path', default=None, help='Where to save ffsubsync.log file (must be an existing '
-                        'directory).')
+    parser.add_argument('--log-dir-path', default=None,
+                        help='Where to save ffsubsync.log file (must be an existing directory).')
     parser.add_argument('--vlc-mode', action='store_true', help=argparse.SUPPRESS)
     parser.add_argument('--gui-mode', action='store_true', help=argparse.SUPPRESS)
     parser.add_argument('--skip-sync', action='store_true', help=argparse.SUPPRESS)
